diff --git a/bindings/c/include/SFML/Graphics/RenderWindow.h b/bindings/c/include/SFML/Graphics/RenderWindow.h
index 922c8ad7..8d12339a 100644
--- a/bindings/c/include/SFML/Graphics/RenderWindow.h
+++ b/bindings/c/include/SFML/Graphics/RenderWindow.h
@@ -141,7 +141,7 @@ CSFML_API sfBool sfRenderWindow_WaitEvent(sfRenderWindow* renderWindow, sfEvent*
/// \param enabled : sfTrue to enable v-sync, sfFalse to deactivate
///
////////////////////////////////////////////////////////////
-CSFML_API void sfRenderWindow_UseVerticalSync(sfRenderWindow* renderWindow, sfBool enabled);
+CSFML_API void sfRenderWindow_EnableVerticalSync(sfRenderWindow* renderWindow, sfBool enabled);
////////////////////////////////////////////////////////////
/// Show or hide the mouse cursor on a window
diff --git a/bindings/c/include/SFML/Window/Window.h b/bindings/c/include/SFML/Window/Window.h
index 3d7396c2..4d315452 100644
--- a/bindings/c/include/SFML/Window/Window.h
+++ b/bindings/c/include/SFML/Window/Window.h
@@ -166,7 +166,7 @@ CSFML_API sfBool sfWindow_WaitEvent(sfWindow* window, sfEvent* event);
/// \param enabled : sfTrue to enable v-sync, sfFalse to deactivate
///
////////////////////////////////////////////////////////////
-CSFML_API void sfWindow_UseVerticalSync(sfWindow* window, sfBool enabled);
+CSFML_API void sfWindow_EnableVerticalSync(sfWindow* window, sfBool enabled);
////////////////////////////////////////////////////////////
/// Show or hide the mouse cursor on a window
diff --git a/bindings/c/src/SFML/Graphics/RenderWindow.cpp b/bindings/c/src/SFML/Graphics/RenderWindow.cpp
index ff0f3315..c6368073 100644
--- a/bindings/c/src/SFML/Graphics/RenderWindow.cpp
+++ b/bindings/c/src/SFML/Graphics/RenderWindow.cpp
@@ -204,9 +204,9 @@ sfBool sfRenderWindow_WaitEvent(sfRenderWindow* renderWindow, sfEvent* event)
////////////////////////////////////////////////////////////
/// Enable / disable vertical synchronization on a window
////////////////////////////////////////////////////////////
-void sfRenderWindow_UseVerticalSync(sfRenderWindow* renderWindow, sfBool enabled)
+void sfRenderWindow_EnableVerticalSync(sfRenderWindow* renderWindow, sfBool enabled)
{
- CSFML_CALL(renderWindow, UseVerticalSync(enabled == sfTrue));
+ CSFML_CALL(renderWindow, EnableVerticalSync(enabled == sfTrue));
}
diff --git a/bindings/c/src/SFML/Window/Window.cpp b/bindings/c/src/SFML/Window/Window.cpp
index 19bd96e1..5f4cab18 100644
--- a/bindings/c/src/SFML/Window/Window.cpp
+++ b/bindings/c/src/SFML/Window/Window.cpp
@@ -196,9 +196,9 @@ sfBool sfWindow_WaitEvent(sfWindow* window, sfEvent* event)
////////////////////////////////////////////////////////////
/// Enable / disable vertical synchronization on a window
////////////////////////////////////////////////////////////
-void sfWindow_UseVerticalSync(sfWindow* window, sfBool enabled)
+void sfWindow_EnableVerticalSync(sfWindow* window, sfBool enabled)
{
- CSFML_CALL(window, UseVerticalSync(enabled == sfTrue))
+ CSFML_CALL(window, EnableVerticalSync(enabled == sfTrue))
}
diff --git a/bindings/dotnet/extlibs/csfml-audio-2.dll b/bindings/dotnet/extlibs/csfml-audio-2.dll
index 52123c25..ccec009b 100644
Binary files a/bindings/dotnet/extlibs/csfml-audio-2.dll and b/bindings/dotnet/extlibs/csfml-audio-2.dll differ
diff --git a/bindings/dotnet/extlibs/csfml-graphics-2.dll b/bindings/dotnet/extlibs/csfml-graphics-2.dll
index 58f3cb44..2cd357e8 100644
Binary files a/bindings/dotnet/extlibs/csfml-graphics-2.dll and b/bindings/dotnet/extlibs/csfml-graphics-2.dll differ
diff --git a/bindings/dotnet/extlibs/csfml-window-2.dll b/bindings/dotnet/extlibs/csfml-window-2.dll
index 3f51d0b4..37ce60ec 100644
Binary files a/bindings/dotnet/extlibs/csfml-window-2.dll and b/bindings/dotnet/extlibs/csfml-window-2.dll differ
diff --git a/bindings/dotnet/src/Graphics/RenderWindow.cs b/bindings/dotnet/src/Graphics/RenderWindow.cs
index 114d7897..265defe0 100644
--- a/bindings/dotnet/src/Graphics/RenderWindow.cs
+++ b/bindings/dotnet/src/Graphics/RenderWindow.cs
@@ -152,9 +152,9 @@ namespace SFML
///
/// True to enable v-sync, false to deactivate
////////////////////////////////////////////////////////////
- public override void UseVerticalSync(bool enable)
+ public override void EnableVerticalSync(bool enable)
{
- sfRenderWindow_UseVerticalSync(This, enable);
+ sfRenderWindow_EnableVerticalSync(This, enable);
}
////////////////////////////////////////////////////////////
@@ -555,7 +555,7 @@ namespace SFML
static extern ContextSettings sfRenderWindow_GetSettings(IntPtr This);
[DllImport("csfml-graphics-2", CallingConvention = CallingConvention.Cdecl), SuppressUnmanagedCodeSecurity]
- static extern void sfRenderWindow_UseVerticalSync(IntPtr This, bool Enable);
+ static extern void sfRenderWindow_EnableVerticalSync(IntPtr This, bool Enable);
[DllImport("csfml-graphics-2", CallingConvention = CallingConvention.Cdecl), SuppressUnmanagedCodeSecurity]
static extern void sfRenderWindow_ShowMouseCursor(IntPtr This, bool Show);
diff --git a/bindings/dotnet/src/Window/Window.cs b/bindings/dotnet/src/Window/Window.cs
index 861b0223..f1a34dcc 100644
--- a/bindings/dotnet/src/Window/Window.cs
+++ b/bindings/dotnet/src/Window/Window.cs
@@ -187,9 +187,9 @@ namespace SFML
///
/// True to enable v-sync, false to deactivate
////////////////////////////////////////////////////////////
- public virtual void UseVerticalSync(bool enable)
+ public virtual void EnableVerticalSync(bool enable)
{
- sfWindow_UseVerticalSync(This, enable);
+ sfWindow_EnableVerticalSync(This, enable);
}
////////////////////////////////////////////////////////////
@@ -618,7 +618,7 @@ namespace SFML
static extern ContextSettings sfWindow_GetSettings(IntPtr This);
[DllImport("csfml-window-2", CallingConvention = CallingConvention.Cdecl), SuppressUnmanagedCodeSecurity]
- static extern void sfWindow_UseVerticalSync(IntPtr This, bool Enable);
+ static extern void sfWindow_EnableVerticalSync(IntPtr This, bool Enable);
[DllImport("csfml-window-2", CallingConvention = CallingConvention.Cdecl), SuppressUnmanagedCodeSecurity]
static extern void sfWindow_ShowMouseCursor(IntPtr This, bool Show);
diff --git a/include/SFML/Graphics/Drawable.hpp b/include/SFML/Graphics/Drawable.hpp
index eec721e8..d1644ea5 100644
--- a/include/SFML/Graphics/Drawable.hpp
+++ b/include/SFML/Graphics/Drawable.hpp
@@ -155,12 +155,12 @@ public :
/// See Scale to add a factor based on the previous scale instead.
/// The default scale of a drawable object is (1, 1).
///
- /// \param scale New scale factors
+ /// \param factors New scale factors
///
/// \see Scale, SetScaleX, SetScaleY, GetScale
///
////////////////////////////////////////////////////////////
- void SetScale(const Vector2f& scale);
+ void SetScale(const Vector2f& factors);
////////////////////////////////////////////////////////////
/// \brief Set the X scale factor of the object
diff --git a/include/SFML/Window/Window.hpp b/include/SFML/Window/Window.hpp
index 87bb7d11..90959147 100644
--- a/include/SFML/Window/Window.hpp
+++ b/include/SFML/Window/Window.hpp
@@ -265,7 +265,7 @@ public :
/// \param enabled True to enable v-sync, false to deactivate
///
////////////////////////////////////////////////////////////
- void UseVerticalSync(bool enabled);
+ void EnableVerticalSync(bool enabled);
////////////////////////////////////////////////////////////
/// \brief Show or hide the mouse cursor
diff --git a/src/SFML/Graphics/Drawable.cpp b/src/SFML/Graphics/Drawable.cpp
index 88fd6f1b..6bb7f53f 100644
--- a/src/SFML/Graphics/Drawable.cpp
+++ b/src/SFML/Graphics/Drawable.cpp
@@ -99,10 +99,10 @@ void Drawable::SetScale(float factorX, float factorY)
////////////////////////////////////////////////////////////
-void Drawable::SetScale(const Vector2f& scale)
+void Drawable::SetScale(const Vector2f& factors)
{
- SetScaleX(scale.x);
- SetScaleY(scale.y);
+ SetScaleX(factors.x);
+ SetScaleY(factors.y);
}
diff --git a/src/SFML/Graphics/Shape.cpp b/src/SFML/Graphics/Shape.cpp
index aa5a2c9f..ed80496f 100644
--- a/src/SFML/Graphics/Shape.cpp
+++ b/src/SFML/Graphics/Shape.cpp
@@ -112,9 +112,9 @@ void Shape::SetPointOutlineColor(unsigned int index, const Color& color)
////////////////////////////////////////////////////////////
-void Shape::SetOutlineWidth(float width)
+void Shape::SetOutlineThickness(float thickness)
{
- myOutline = width;
+ myOutline = thickness;
}
@@ -140,7 +140,7 @@ const Color& Shape::GetPointOutlineColor(unsigned int index) const
////////////////////////////////////////////////////////////
-float Shape::GetOutlineWidth() const
+float Shape::GetOutlineThickness() const
{
return myOutline;
}
@@ -170,7 +170,7 @@ Shape Shape::Line(const Vector2f& p1, const Vector2f& p2, float thickness, const
shape.AddPoint(p2 - normal, color, outlineColor);
shape.AddPoint(p2 + normal, color, outlineColor);
shape.AddPoint(p1 + normal, color, outlineColor);
- shape.SetOutlineWidth(outline);
+ shape.SetOutlineThickness(outline);
// Compile it
shape.Compile();
@@ -188,7 +188,7 @@ Shape Shape::Rectangle(float left, float top, float width, float height, const C
shape.AddPoint(Vector2f(left + width, top), color, outlineColor);
shape.AddPoint(Vector2f(left + width, top + height), color, outlineColor);
shape.AddPoint(Vector2f(left, top + height), color, outlineColor);
- shape.SetOutlineWidth(outline);
+ shape.SetOutlineThickness(outline);
// Compile it
shape.Compile();
@@ -227,7 +227,7 @@ Shape Shape::Circle(const Vector2f& center, float radius, const Color& color, fl
}
// Compile it
- shape.SetOutlineWidth(outline);
+ shape.SetOutlineThickness(outline);
shape.Compile();
return shape;
diff --git a/src/SFML/Window/GlContext.hpp b/src/SFML/Window/GlContext.hpp
index c20f484f..9c422674 100644
--- a/src/SFML/Window/GlContext.hpp
+++ b/src/SFML/Window/GlContext.hpp
@@ -127,7 +127,7 @@ public :
/// \param enabled True to enable v-sync, false to deactivate
///
////////////////////////////////////////////////////////////
- virtual void UseVerticalSync(bool enabled) = 0;
+ virtual void EnableVerticalSync(bool enabled) = 0;
////////////////////////////////////////////////////////////
/// \brief Make the current thread's reference context active
diff --git a/src/SFML/Window/Linux/GlxContext.cpp b/src/SFML/Window/Linux/GlxContext.cpp
index 7b15fee4..3cf744e1 100644
--- a/src/SFML/Window/Linux/GlxContext.cpp
+++ b/src/SFML/Window/Linux/GlxContext.cpp
@@ -139,7 +139,7 @@ void GlxContext::Display()
////////////////////////////////////////////////////////////
-void GlxContext::UseVerticalSync(bool enabled)
+void GlxContext::EnableVerticalSync(bool enabled)
{
const GLubyte* name = reinterpret_cast("glXSwapIntervalSGI");
PFNGLXSWAPINTERVALSGIPROC glXSwapIntervalSGI = reinterpret_cast(glXGetProcAddress(name));
diff --git a/src/SFML/Window/Linux/GlxContext.hpp b/src/SFML/Window/Linux/GlxContext.hpp
index 96b9621f..fc50d2cd 100644
--- a/src/SFML/Window/Linux/GlxContext.hpp
+++ b/src/SFML/Window/Linux/GlxContext.hpp
@@ -96,7 +96,7 @@ public :
/// \param enabled : True to enable v-sync, false to deactivate
///
////////////////////////////////////////////////////////////
- virtual void UseVerticalSync(bool enabled);
+ virtual void EnableVerticalSync(bool enabled);
private :
diff --git a/src/SFML/Window/OSX/SFContext.hpp b/src/SFML/Window/OSX/SFContext.hpp
index 0718da51..58b4d43b 100644
--- a/src/SFML/Window/OSX/SFContext.hpp
+++ b/src/SFML/Window/OSX/SFContext.hpp
@@ -104,7 +104,7 @@ public:
/// \param enabled : True to enable v-sync, false to deactivate
///
////////////////////////////////////////////////////////////
- virtual void UseVerticalSync(bool enabled);
+ virtual void EnableVerticalSync(bool enabled);
protected:
////////////////////////////////////////////////////////////
@@ -141,4 +141,4 @@ private:
} // namespace sf
-#endif // SFML_AGLCONTEXT_HPP
+#endif // SFML_SFCONTEXT_HPP
diff --git a/src/SFML/Window/OSX/SFContext.mm b/src/SFML/Window/OSX/SFContext.mm
index 24bf07a5..7f632ee9 100644
--- a/src/SFML/Window/OSX/SFContext.mm
+++ b/src/SFML/Window/OSX/SFContext.mm
@@ -99,7 +99,7 @@ void SFContext::Display()
////////////////////////////////////////////////////////////
-void SFContext::UseVerticalSync(bool enabled)
+void SFContext::EnableVerticalSync(bool enabled)
{
// Make compiler happy
#ifdef USE_OS_X_VERSION_10_4
diff --git a/src/SFML/Window/Win32/WglContext.cpp b/src/SFML/Window/Win32/WglContext.cpp
index 72e850d1..8d1eaf56 100644
--- a/src/SFML/Window/Win32/WglContext.cpp
+++ b/src/SFML/Window/Win32/WglContext.cpp
@@ -130,7 +130,7 @@ void WglContext::Display()
////////////////////////////////////////////////////////////
-void WglContext::UseVerticalSync(bool enabled)
+void WglContext::EnableVerticalSync(bool enabled)
{
PFNWGLSWAPINTERVALEXTPROC wglSwapIntervalEXT = reinterpret_cast(wglGetProcAddress("wglSwapIntervalEXT"));
if (wglSwapIntervalEXT)
diff --git a/src/SFML/Window/Win32/WglContext.hpp b/src/SFML/Window/Win32/WglContext.hpp
index d0c2d371..b0bb5333 100644
--- a/src/SFML/Window/Win32/WglContext.hpp
+++ b/src/SFML/Window/Win32/WglContext.hpp
@@ -95,7 +95,7 @@ public :
/// \param enabled : True to enable v-sync, false to deactivate
///
////////////////////////////////////////////////////////////
- virtual void UseVerticalSync(bool enabled);
+ virtual void EnableVerticalSync(bool enabled);
private :
diff --git a/src/SFML/Window/Window.cpp b/src/SFML/Window/Window.cpp
index b1859aa5..0454dfbc 100644
--- a/src/SFML/Window/Window.cpp
+++ b/src/SFML/Window/Window.cpp
@@ -232,10 +232,10 @@ bool Window::WaitEvent(Event& event)
////////////////////////////////////////////////////////////
-void Window::UseVerticalSync(bool enabled)
+void Window::EnableVerticalSync(bool enabled)
{
if (SetActive())
- myContext->UseVerticalSync(enabled);
+ myContext->EnableVerticalSync(enabled);
}
@@ -431,8 +431,8 @@ void Window::Initialize()
{
// Setup default behaviours (to get a consistent behaviour across different implementations)
Show(true);
- UseVerticalSync(false);
ShowMouseCursor(true);
+ EnableVerticalSync(false);
EnableKeyRepeat(true);
// Reset frame time
diff --git a/bindings/c/include/SFML/Graphics/Shape.h b/bindings/c/include/SFML/Graphics/Shape.h
index 74269230..4ddb3169 100644
--- a/bindings/c/include/SFML/Graphics/Shape.h
+++ b/bindings/c/include/SFML/Graphics/Shape.h
@@ -49,7 +49,7 @@ CSFML_API sfShape* sfShape_Create(void);
/// \param p2x, p2y : Position second point
/// \param thickness : Line thickness
/// \param color : Color used to draw the line
/// \param outline : Outline width
/// \param outlineColor : Color used to draw the outline
///
////////////////////////////////////////////////////////////
@@ -61,7 +61,7 @@ CSFML_API sfShape* sfShape_CreateLine(float p1x, float p1y, float p2x, float p2y
/// \param left, top : Top-left corner of the rectangle
/// \param width, height : Size of the rectangle
/// \param color : Color used to fill the rectangle
/// \param outline : Outline width
/// \param outlineColor : Color used to draw the outline
///
////////////////////////////////////////////////////////////
@@ -73,7 +73,7 @@ CSFML_API sfShape* sfShape_CreateRectangle(float left, float top, float width, f
/// \param x, y : Position of the center
/// \param radius : Radius
/// \param color : Color used to fill the circle
/// \param outline : Outline width
/// \param outlineColor : Color used to draw the outline
///
////////////////////////////////////////////////////////////
@@ -368,23 +368,23 @@ CSFML_API void sfShape_EnableFill(sfShape* shape, sfBool enable);
CSFML_API void sfShape_EnableOutline(sfShape* shape, sfBool enable);
////////////////////////////////////////////////////////////
/// Change the width of a shape outline
///
/// \param shape : Shape to modify
/// \param width : New width
///
////////////////////////////////////////////////////////////
-CSFML_API void sfShape_SetOutlineWidth(sfShape* shape, float width);
+CSFML_API void sfShape_SetOutlineThickness(sfShape* shape, float thickness);
////////////////////////////////////////////////////////////
/// Get the width of a shape outline
///
/// \param shape : Shape to read
///
/// \param return Current outline width
///
////////////////////////////////////////////////////////////
-CSFML_API float sfShape_GetOutlineWidth(const sfShape* shape);
+CSFML_API float sfShape_GetOutlineThickness(const sfShape* shape);
////////////////////////////////////////////////////////////
/// Get the number of points composing a shape
@@ -49,7 +49,7 @@ CSFML_API sfShape* sfShape_Create(void);
/// \param thickness : Line thickness
/// \param color : Color used to draw the line
-/// \param outline : Outline width
+/// \param outline : Outline thickness
/// \param outlineColor : Color used to draw the outline
///
@@ -61,7 +61,7 @@ CSFML_API sfShape* sfShape_CreateLine(float p1x, float p1y, float p2x, float p2y
/// \param width, height : Size of the rectangle
/// \param color : Color used to fill the rectangle
-/// \param outline : Outline width
+/// \param outline : Outline thickness
/// \param outlineColor : Color used to draw the outline
///
@@ -73,7 +73,7 @@ CSFML_API sfShape* sfShape_CreateRectangle(float left, float top, float width, f
/// \param radius : Radius
/// \param color : Color used to fill the circle
-/// \param outline : Outline width
+/// \param outline : Outline thickness
/// \param outlineColor : Color used to draw the outline
///
@@ -368,23 +368,23 @@ CSFML_API void sfShape_EnableFill(sfShape* shape, sfBool enable);
CSFML_API void sfShape_EnableOutline(sfShape* shape, sfBool enable);
////////////////////////////////////////////////////////////
-/// Change the width of a shape outline
+/// Change the thickness of a shape outline
///
/// \param shape : Shape to modify
@@ -368,23 +368,23 @@ CSFML_API void sfShape_EnableFill(sfShape* shape, sfBool enable);
///
/// \param shape : Shape to modify
-/// \param width : New width
+/// \param thickness : New thickness
///
////////////////////////////////////////////////////////////
@@ -368,23 +368,23 @@ CSFML_API void sfShape_EnableFill(sfShape* shape, sfBool enable);
////////////////////////////////////////////////////////////
-/// Get the width of a shape outline
+/// Get the thickness of a shape outline
///
/// \param shape : Shape to read
@@ -368,23 +368,23 @@ CSFML_API void sfShape_EnableFill(sfShape* shape, sfBool enable);
/// \param shape : Shape to read
///
-/// \param return Current outline width
+/// \param return Current outline thickness
///
////////////////////////////////////////////////////////////
diff --git a/bindings/c/src/SFML/Graphics/Shape.cpp b/bindings/c/src/SFML/Graphics/Shape.cpp
index d0d1c481..5105cf72 100644
--- a/bindings/c/src/SFML/Graphics/Shape.cpp
+++ b/bindings/c/src/SFML/Graphics/Shape.cpp
@@ -368,20 +368,20 @@ void sfShape_EnableOutline(sfShape* shape, sfBool enable)
////////////////////////////////////////////////////////////
/// Change the width of a shape outline
////////////////////////////////////////////////////////////
-void sfShape_SetOutlineWidth(sfShape* shape, float width)
+void sfShape_SetOutlineThickness(sfShape* shape, float thickness)
{
- CSFML_CALL(shape, SetOutlineWidth(width))
+ CSFML_CALL(shape, SetOutlineThickness(thickness))
}
////////////////////////////////////////////////////////////
/// Get the width of a shape outline
////////////////////////////////////////////////////////////
-float sfShape_GetOutlineWidth(const sfShape* shape)
+float sfShape_GetOutlineThickness(const sfShape* shape)
{
- CSFML_CALL_RETURN(shape, GetOutlineWidth(), 0.f)
+ CSFML_CALL_RETURN(shape, GetOutlineThickness(), 0.f)
}
@@ -368,20 +368,20 @@ void sfShape_EnableOutline(sfShape* shape, sfBool enable)
////////////////////////////////////////////////////////////
-/// Change the width of a shape outline
+/// Change the thickness of a shape outline
////////////////////////////////////////////////////////////
@@ -368,20 +368,20 @@ void sfShape_EnableOutline(sfShape* shape, sfBool enable)
}
////////////////////////////////////////////////////////////
-/// Get the width of a shape outline
+/// Get the thickness of a shape outline
////////////////////////////////////////////////////////////
diff --git a/bindings/dotnet/src/Graphics/Shape.cs b/bindings/dotnet/src/Graphics/Shape.cs
index acfac3f5..3f807e2a 100644
--- a/bindings/dotnet/src/Graphics/Shape.cs
+++ b/bindings/dotnet/src/Graphics/Shape.cs
@@ -186,13 +186,13 @@ namespace SFML
////////////////////////////////////////////////////////////
///
/// Width of the shape outline
///
////////////////////////////////////////////////////////////
- public float OutlineWidth
+ public float OutlineThickness
{
- get {return sfShape_GetOutlineWidth(This);}
- set {sfShape_SetOutlineWidth(This, value);}
+ get {return sfShape_GetOutlineThickness(This);}
+ set {sfShape_SetOutlineThickness(This, value);}
}
////////////////////////////////////////////////////////////
@@ -385,7 +385,7 @@ namespace SFML
" Origin(" + Origin + ")" +
" Color(" + Color + ")" +
" BlendMode(" + BlendMode + ")" +
- " OutlineWidth(" + OutlineWidth + ")" +
+ " OutlineThickness(" + OutlineThickness + ")" +
" PointsCount(" + PointsCount + ")";
}
@@ -533,10 +533,10 @@ namespace SFML
static extern void sfShape_EnableOutline(IntPtr This, bool Enable);
[DllImport("csfml-graphics-2", CallingConvention = CallingConvention.Cdecl), SuppressUnmanagedCodeSecurity]
- static extern void sfShape_SetOutlineWidth(IntPtr This, float Width);
+ static extern void sfShape_SetOutlineThickness(IntPtr This, float Thickness);
[DllImport("csfml-graphics-2", CallingConvention = CallingConvention.Cdecl), SuppressUnmanagedCodeSecurity]
- static extern float sfShape_GetOutlineWidth(IntPtr This);
+ static extern float sfShape_GetOutlineThickness(IntPtr This);
[DllImport("csfml-graphics-2", CallingConvention = CallingConvention.Cdecl), SuppressUnmanagedCodeSecurity]
static extern uint sfShape_GetPointsCount(IntPtr This);
@@ -186,13 +186,13 @@ namespace SFML
////////////////////////////////////////////////////////////
///
- /// Width of the shape outline
+ /// Thickness of the shape outline
///
////////////////////////////////////////////////////////////
diff --git a/include/SFML/Graphics/Shape.hpp b/include/SFML/Graphics/Shape.hpp
index 53b2def3..e6c38eb5 100644
--- a/include/SFML/Graphics/Shape.hpp
+++ b/include/SFML/Graphics/Shape.hpp
@@ -172,12 +172,12 @@ public :
////////////////////////////////////////////////////////////
/// \brief Change the thickness of the shape outline
///
/// \param width New width of the outline
///
- /// \see GetOutlineWidth, EnableOutline
+ /// \see GetOutlineThickness, EnableOutline
///
////////////////////////////////////////////////////////////
- void SetOutlineWidth(float width);
+ void SetOutlineThickness(float thickness);
////////////////////////////////////////////////////////////
/// \brief Get the position of a point
@@ -230,12 +230,12 @@ public :
////////////////////////////////////////////////////////////
/// \brief Get the thickness of the shape outline
///
/// \return Current outline width
///
- /// \see SetOutlineWidth
+ /// \see SetOutlineThickness
///
////////////////////////////////////////////////////////////
- float GetOutlineWidth() const;
+ float GetOutlineThickness() const;
////////////////////////////////////////////////////////////
/// \brief Create a new line
@@ -257,7 +257,7 @@ public :
/// \param p2y Y coordinate of the end point
/// \param thickness Thickness of the line
/// \param color Color of the shape's points
/// \param outline Outline width
/// \param outlineColor Outline color of the shape's points
///
/// \see Rectangle, Circle
@@ -285,7 +285,7 @@ public :
/// \param end End point
/// \param thickness Thickness of the line
/// \param color Color of the shape's points
/// \param outline Outline width
/// \param outlineColor Outline color of the shape's points
///
/// \see Rectangle, Circle
@@ -312,7 +312,7 @@ public :
/// \param width Width of the rectangle
/// \param height Height of the rectangle
/// \param color Color of the shape's points
/// \param outline Outline width
/// \param outlineColor Outline color of the shape's points
///
/// \see Line, Circle
@@ -337,7 +337,7 @@ public :
///
/// \param rectangle Rectangle defining the shape
/// \param color Color of the shape's points
/// \param outline Outline width
/// \param outlineColor Outline color of the shape's points
///
/// \see Line, Circle
@@ -363,7 +363,7 @@ public :
/// \param y Y coordinate of the center
/// \param radius Radius of the circle
/// \param color Color of the shape's points
/// \param outline Outline width
/// \param outlineColor Outline color of the shape's points
///
/// \see Line, Rectangle
@@ -389,7 +389,7 @@ public :
/// \param center Center of the circle
/// \param radius Radius of the circle
/// \param color Color of the shape's points
/// \param outline Outline width
/// \param outlineColor Outline color of the shape's points
///
/// \see Line, Rectangle
@@ -449,7 +449,7 @@ private :
// Member data
////////////////////////////////////////////////////////////
std::vector myPoints; ///< Points composing the shape
- float myOutline; ///< Outline width
+ float myOutline; ///< Outline thickness
bool myIsFillEnabled; ///< Should we draw the inside if the shape ?
bool myIsOutlineEnabled; ///< Should we draw the outline if the shape ?
bool myIsCompiled; ///< Compiled state of the shape
@@ -480,7 +480,7 @@ private :
/// \li outline color
///
/// Shapes have an outline that can be enabled or not. You can
/// control the thickness of the outline with the SetOutlineWidth
/// function.
///
/// They also inherits all the functions from sf::Drawable:
@@ -523,7 +523,7 @@ private :
/// // Enable outline only
/// shape.EnableFill(false);
/// shape.EnableOutline(true);
-/// shape.SetOutlineWidth(10);
+/// shape.SetOutlineThickness(10);
///
/// // Display it
/// window.Draw(shape); // window is a sf::RenderWindow
@@ -172,12 +172,12 @@ public :
/// \brief Change the thickness of the shape outline
///
- /// \param width New width of the outline
+ /// \param thickness New thickness of the outline
///
@@ -230,12 +230,12 @@ public :
/// \brief Get the thickness of the shape outline
///
- /// \return Current outline width
+ /// \return Current outline thickness
///
@@ -257,7 +257,7 @@ public :
/// \param thickness Thickness of the line
/// \param color Color of the shape's points
- /// \param outline Outline width
+ /// \param outline Outline thickness
/// \param outlineColor Outline color of the shape's points
///
@@ -285,7 +285,7 @@ public :
/// \param thickness Thickness of the line
/// \param color Color of the shape's points
- /// \param outline Outline width
+ /// \param outline Outline thickness
/// \param outlineColor Outline color of the shape's points
///
@@ -312,7 +312,7 @@ public :
/// \param height Height of the rectangle
/// \param color Color of the shape's points
- /// \param outline Outline width
+ /// \param outline Outline thickness
/// \param outlineColor Outline color of the shape's points
///
@@ -337,7 +337,7 @@ public :
/// \param rectangle Rectangle defining the shape
/// \param color Color of the shape's points
- /// \param outline Outline width
+ /// \param outline Outline thickness
/// \param outlineColor Outline color of the shape's points
///
@@ -363,7 +363,7 @@ public :
/// \param radius Radius of the circle
/// \param color Color of the shape's points
- /// \param outline Outline width
+ /// \param outline Outline thickness
/// \param outlineColor Outline color of the shape's points
///
@@ -389,7 +389,7 @@ public :
/// \param radius Radius of the circle
/// \param color Color of the shape's points
- /// \param outline Outline width
+ /// \param outline Outline thickness
/// \param outlineColor Outline color of the shape's points
///
@@ -480,7 +480,7 @@ private :
///
/// Shapes have an outline that can be enabled or not. You can
-/// control the thickness of the outline with the SetOutlineWidth
+/// control the thickness of the outline with the SetOutlineThickness
/// function.
///